@@ -13,6 +13,9 @@ local smerger  = require 'string-merger'
 local progress = require "progress"
 local encoder  = require 'encoder'
 local scope    = require 'workspace.scope'
+local lazy     = require 'lazytable'
+local cacher   = require 'lazy-cacher'
+local sp       = require 'bee.subprocess'
 
 ---@class file
 ---@field uri          uri
@@ -27,8 +30,10 @@ local scope    = require 'workspace.scope'
 ---@field state?       parser.state
 ---@field _diffInfo?   table[]
 ---@field cache        table
+---@field id           integer
 
 ---@class files
+---@field lazyCache?   lazy-cacher
 local m = {}
 
 m.watchList      = {}
@@ -49,6 +54,8 @@ end
 
 m.reset()
 
+local fileID = util.counter()
+
 local uriMap = {}
 -- 获取文件的真实uri，但不穿透软链接
 ---@param uri uri
@@ -71,11 +78,11 @@ function m.getRealUri(uri)
     if uri == ruri then
         return ruri
     end
-    if not uriMap[ruri] then
-        uriMap[ruri] = uri
+    if not uriMap[uri] then
+        uriMap[uri] = ruri
         log.warn(('Fix real file uri: %s -> %s'):format(uri, ruri))
     end
-    return uriMap[ruri]
+    return uriMap[uri]
 end
 
 --- 打开文件
@@ -201,6 +208,7 @@ function m.setText(uri, text, isTrust, callback)
     if not m.fileMap[uri] then
         m.fileMap[uri] = {
             uri = uri,
+            id  = fileID(),
         }
         m.fileCount = m.fileCount + 1
         create = true
@@ -470,6 +478,17 @@ function m.eachDll()
     return pairs(map)
 end
 
+function m.getLazyCache()
+    if not m.lazyCache then
+        local cachePath = string.format('%s/cache/%d'
+            , LOGPATH
+            , sp.get_id()
+        )
+        m.lazyCache = cacher(cachePath, log.error)
+    end
+    return m.lazyCache
+end
+
 function m.compileState(uri, text)
     local ws     = require 'workspace'
     local client = require 'client'
@@ -517,21 +536,37 @@ function m.compileState(uri, text)
         state.uri = uri
         state.lua = text
         state.ast.uri = uri
+
         local clock = os.clock()
         parser.luadoc(state)
         local passed = os.clock() - clock
         if passed > 0.1 then
             log.warn(('Parse LuaDoc of [%s] takes [%.3f] sec, size [%.3f] kb.'):format(uri, passed, #text / 1000))
         end
-        m.astCount = m.astCount + 1
-        local removed
-        setmetatable(state, {__gc = function ()
-            if removed then
-                return
+
+        local file = m.fileMap[uri]
+        if LAZY and not file.trusted then
+            state.pushError = nil
+            local cache = m.getLazyCache()
+            local id = ('%d'):format(file.id)
+            clock = os.clock()
+            state = lazy.build(state, cache:writterAndReader(id)):entry()
+            passed = os.clock() - clock
+            if passed > 0.1 then
+                log.warn(('Convert lazy-table for [%s] takes [%.3f] sec, size [%.3f] kb.'):format(uri, passed, #text / 1000))
             end
-            removed = true
-            m.astCount = m.astCount - 1
-        end})
+        else
+            m.astCount = m.astCount + 1
+            local removed
+            setmetatable(state, {__gc = function ()
+                if removed then
+                    return
+                end
+                removed = true
+                m.astCount = m.astCount - 1
+            end})
+        end
+
         return state
     else
         log.error('Compile failed:', uri, err)
